function createFunctionBlockFromMatrices(m0,pre,post)
% CREATEFUNCTIONBLOCKFROMMATRICES  Creates the function block modelling the
% Petri Net supervisor given by matrices. The SCL file is saved as
% SUPERVISOR.SCL in the current folder.
%
%   Syntax:
%   createFunctionBlockFromMatrices(m0,pre,post), where:
% * m0 is the column vector representing the initial marking;
% * pre and post are the pre and post incidence matrices;
% 

    init;
    assert(~isempty(m0) && ~isempty(pre) && ~isempty(post),'Matrices must be non empty');
    assert(length(m0)==size(pre,1) && length(m0)==size(post,1),'The given matrices have wrong sizes');
    assert(isequal(size(pre),size(post)),'The given matrices have wrong sizes');
    mapE = getNewMap();
    mapN = getNewMap();
    nT = size(pre,2);
    nP = size(pre,1);
    
    for i=1:nT
        mapE=insertPairToMap(i,['t',num2str(i)],mapE);
    end
    for i=1:nP
        mapN=insertPairToMap(i,['p',num2str(i)],mapN);
    end
    G=struct('M0',m0,'PRE',pre,'POST',post);
    createFunctionBlock(G,mapN,mapE,true);
end