function [  ] = createFunctionBlock(G,mapN,mapE,PN)
% CREATEFUNCTIONBLOCK  Creates and writes a function block to a file named 
% SUPERVISOR_FB.SCL.
% 
%
%   Syntax:
%   createFunctionBlock(G,mapN,mapE,PN), where:
% * G is the model structure;
% * mapN is the map associating to each numbered place/state a string;
% * mapE is the map associating to each numbered transition/event a string;
% * PN is true if the given arguments represent a PN, otherwise they represent an automaton;
% 
    defineEventDetectors=@defineTriggerEventDetectors;
    readEventFunc = @readTriggerEvent;
    getEventFunc = @getTriggerEvent;

    if(PN)
        initStateFunc = @initializePN;
        detectAndProcess = @detectAndProcessPN;
        defineVars=@defineVarsPN;
        defineExtraOutputVars = @defineExtraOutputVarsPN;
        defineExtraInputVars=@defineExtraInputVarsPN;
        finalizeStateFunc=@finalizeStateFuncPN;
    else
        initStateFunc = @initializeGraph;
        detectAndProcess = @detectAndProcessGraph;
        defineVars=@defineVarsGraph;
        defineExtraOutputVars = @defineExtraOutputVarsGraph;
        defineExtraInputVars=@defineExtraInputVarsGraph;
        finalizeStateFunc=@finalizeStateFuncGraph;
    end
    
    initWriterFunc=@()initWriter(G,mapN,mapE, initStateFunc,defineVars,defineExtraOutputVars,defineEventDetectors,defineExtraInputVars);
    cycleWriterFunc=@()cycleWriter(G,mapN,mapE,detectAndProcess,readEventFunc,getEventFunc);
    firstTimeFinalizerWriterFunc=@()firstTimeFinalizerWriter(G,mapN,mapE,finalizeStateFunc);

    s = functionBlockWriter( initWriterFunc,cycleWriterFunc,firstTimeFinalizerWriterFunc,'SUPERVISOR_FB');
    saveToFile( s,'SUPERVISOR.SCL');
        
end

