function [ s ] = detectAndProcessGenericGraph( G,mapN,mapE,getEvent,getOutputVarNameFunc )
% DETECTANDPROCESSGENERICGRAPH Creates the SCL code that processes the
% happened events and updates the automaton state.
% 
%
%   Syntax:
%   detectAndProcessGenericGraph( G,mapN,mapE,getEvent,getOutputVarNameFunc )
% * G is the model structure;
% * mapN is the map associating to each numbered place/state a string;
% * mapE is the map associating to each numbered transition/event a string;
% * getEvent returns as SCL code the boolean condition telling if the i-th
% event in the map happened;
% * getOutputVarNameFunc function that returns the name of the variable associated to the i-th enabler.
% 
    s=''; 
    s=insertLine(s,'(*DETECTING EVENTS, STATE UPDATE, OUTPUT ENABLING*)');
    for i=1:length(mapE)
        s=insertLine(s,['IF ',getEvent( i,mapE ),' THEN']);
        s=insertLine(s,setVar(getContinueSearchVar,true));
        [statesToExplore,destStates]=getStatesAdmittingArc(G.graph,i);
        for j=1:length(statesToExplore)
           %if the automaton is in this possible state
           s=insertLine(s,['IF ',getContinueSearchVar(),' AND ',getStateName(statesToExplore(j),mapN),' THEN ']);
           %disable state and disable its admissible events
           s=insertLine(s,updateStateGenericGraph( G.graph,mapN,mapE, statesToExplore(j), false,getOutputVarNameFunc ));
           %enable new state and enable its admissible events
           s=insertLine(s,updateStateGenericGraph( G.graph,mapN,mapE, destStates(j), true,getOutputVarNameFunc ));
           s=insertLine(s,setVar(getContinueSearchVar,false));
           s=insertLine(s,'END_IF;');
        end
        s=insertLine(s,'END_IF;');
    end
end

