function [ s ] = detectAndProcessGenericPN( G,mapN,mapE,getEvent,getOutputVarNameFunc )
% DETECTANDPROCESSGENERICPN  Creates the SCL code that processes the
% happened events by firing the associated transitions.
% 
%
%   Syntax:
%   detectAndProcessGenericPN( G,mapN,mapE,getEvent,getOutputVarNameFunc ), where:
% * G is the model structure;
% * mapN is the map associating to each numbered place/state a string;
% * mapE is the map associating to each numbered transition/event a string;
% * getEvent returns as SCL code the boolean condition telling if the i-th
% event in the map happened;
% * getOutputVarNameFunc returns the name of the output variable enabling
% the i-th event in the map.
% 
    s='';
    %updating FBs
    s=insertLine(s,'');
    
    s=insertLine(s,'(*UPDATE MARKING BASED ON THE OCCURRED EVENTS*)');
    for i=1:length(mapE)
        s=insertLine(s,['IF ',getEvent( i,mapE ),' THEN']);
        s=insertLine(s,fireTransitionCode( i,G ));
        s=insertLine(s,'END_IF;');
    end
    s=insertLine(s,'(*ENABLE CURRENT ENABLED TRANSITIONS*)');
    for i=1:length(mapE)
        isEnabledVar = getTempVarName();
        s=insertLine(s,setVar( isEnabledVar,true));
        s=insertLine(s,checkEnTransitionCode( i,isEnabledVar,G));
        s=insertLine(s,['IF ',isEnabledVar,' THEN']);
        s=insertLine(s,setVar( getOutputVarNameFunc(i,mapE),true));
        s=insertLine(s,'ELSE');
        s=insertLine(s,setVar( getOutputVarNameFunc(i,mapE),false));
        s=insertLine(s,'END_IF;');
    end
end

